@@ -15,11 +15,11 @@ from drakaina import ENV_AUTH_SCOPES
 from drakaina import ENV_IS_AUTHENTICATED
 from drakaina import ENV_USER_ID
 from drakaina.contrib import django as default_settings
+from drakaina.contrib.django.views import RPCView
 from drakaina.contrib.jwt.errors import InvalidJWTTokenError
 from drakaina.contrib.jwt.utils import decode_jwt_token
 from drakaina.exceptions import AuthenticationFailedError
 from drakaina.exceptions import ForbiddenError
-from drakaina.rpc_protocols import BaseRPCProtocol
 
 __all__ = ("JWTAuthenticationMiddleware",)
 
@@ -28,7 +28,7 @@ ARG_PREFIX = "DRAKAINA_"
 
 
 class DjangoRPCView(Protocol):
-    handler: BaseRPCProtocol
+    cls: RPCView
 
     def __call__(self, request: HttpRequest, *args, **kwargs) -> HttpResponse:
         ...
@@ -54,20 +54,21 @@ class JWTAuthenticationMiddleware:
 
     def __init__(self, view: DjangoRPCView):
         assert hasattr(
-            getattr(view, "cls", None),
+            view.cls,
             "handler",
         ), "The view must contain the BaseRPCProtocol implementation instance."
 
         self._rpc_view = view
-        self._rpc_handler = view.cls.handler  # noqa
+        self._rpc_handler = view.cls.handler
 
         self.credentials_required = get_settings_arg("CREDENTIALS_REQUIRED")
         self.prefix = get_settings_arg("JWT_PREFIX")
         self.cookie_key = get_settings_arg("JWT_COOKIE_KEY")
         self.use_cookies = get_settings_arg("JWT_USE_COOKIES")
         self.algorithms = get_settings_arg("JWT_ALGORITHMS")
-        self.secret_key = get_settings_arg("JWT_SECRET_KEY")
-        self.public_key = get_settings_arg("JWT_PUBLIC_KEY")
+        secret_key = get_settings_arg("JWT_SECRET_KEY")
+        public_key = get_settings_arg("JWT_PUBLIC_KEY")
+        self.__verify_key = secret_key or public_key
         self.decode_options = get_settings_arg("JWT_DECODE_OPTIONS")
         self.verify_values = get_settings_arg("JWT_VERIFY_VALUES")
         self.leeway = get_settings_arg("JWT_LEEWAY")
@@ -108,8 +109,7 @@ class JWTAuthenticationMiddleware:
             payload = decode_jwt_token(
                 token,
                 algorithms=self.algorithms,
-                signing_key=self.secret_key,
-                verify_key=self.public_key,
+                verify_key=self.__verify_key,
                 verify=True,
                 decode_options=self.decode_options,
                 verify_values=self.verify_values,
@@ -141,7 +141,7 @@ class JWTAuthenticationMiddleware:
         if self.use_cookies:
             return request.COOKIES.get(self.cookie_key)
         else:
-            auth_header = request.META.get("Authorization")
+            auth_header = request.headers.get("Authorization")
             if auth_header is None:
                 return None
 
@@ -170,7 +170,7 @@ class JWTAuthenticationMiddleware:
     ) -> Optional[UserModel]:
         user_id = payload.get(self.user_id_field)
         if user_id is None:
-            return None  # todo: try returns request.user
+            return getattr(request, "user", None)
         return UserModel.objects.get(pk=user_id)
 
     def _error_response(self, error: Exception) -> HttpResponse:
