@@ -1,7 +1,7 @@
+from __future__ import annotations
+
 from typing import Any
-from typing import Optional
 from typing import Type
-from typing import Union
 
 from drakaina import rpc_registry
 from drakaina.exceptions import InternalServerError
@@ -29,8 +29,8 @@ class BaseRPCProtocol:
 
     def __init__(
         self,
-        registry: Optional[RPCRegistry] = None,
-        serializer: Optional[BaseSerializer] = None,
+        registry: RPCRegistry | None = None,
+        serializer: BaseSerializer | None = None,
     ):
         self.registry = registry if registry is not None else rpc_registry
         self.serializer = serializer
@@ -40,10 +40,10 @@ class BaseRPCProtocol:
     def handle_raw_request(
         self,
         raw_data: bytes,
-        request: Optional[Any] = None,
+        request: Any | None = None,
     ) -> bytes:
-        """Accepts raw data, serializes, processes the RPC request,
-        and returns the deserialized result.
+        """Accepts raw data, deserializes, processes the RPC request,
+        and returns the serialized result.
 
         :param raw_data:
             Raw request data.
@@ -53,7 +53,7 @@ class BaseRPCProtocol:
             a remote procedure.
         :type request: Any
         :return:
-            Deserialized RPC response data.
+            Serialized RPC response data.
 
         """
         try:
@@ -72,33 +72,21 @@ class BaseRPCProtocol:
 
     def get_raw_error(
         self,
-        error: Union[RPCError, Exception, Type[Exception]],
+        error: RPCError | Type[RPCError] | Exception | Type[Exception],
     ) -> bytes:
-        """Returns the deserialized error object.
+        """Returns the serialized error object.
 
         :param error:
             The instance or class of the error.
-        :type error: RPCError | Type[RPCError] | Exception
+        :type error: RPCError | Type[RPCError] | Exception | Type[Exception]
         :return:
             Raw error data.
 
         """
-
-        if isinstance(error, type) and issubclass(error, Exception):
-            error = error()
-
-        if isinstance(error, self.base_error_class):
-            rpc_error = error
-        else:
-            rpc_error_class = self._errors_map.get(
-                type(error),
-                self.default_error_class,
-            )
-            rpc_error = rpc_error_class(str(error))
-
+        rpc_error = self.handle_error(error)
         return self.serializer.serialize(rpc_error.as_dict())
 
-    def handle(self, rpc_request: Any, request: Optional[Any] = None) -> Any:
+    def handle(self, rpc_request: Any, request: Any | None = None) -> Any:
         """Handles a procedure call.
 
         :param rpc_request:
@@ -114,12 +102,40 @@ class BaseRPCProtocol:
             "You must implement the `handle` method in the child class",
         )
 
+    def handle_error(
+        self,
+        error: RPCError | Type[RPCError] | Exception | Type[Exception],
+    ) -> RPCError:
+        """Returns an exception object corresponding to the ROC protocol.
+
+        :param error:
+            The instance or class of the error.
+        :type error: RPCError | Type[RPCError] | Exception | Type[Exception]
+        :returns: Protocol specific error object.
+        :rtype: RPCError
+
+        """
+
+        if isinstance(error, type) and issubclass(error, Exception):
+            error = error()
+
+        if isinstance(error, self.base_error_class):
+            return error
+        else:
+            rpc_error_class = self._errors_map.get(
+                type(error),
+                self.default_error_class,
+            )
+            return rpc_error_class(str(error))
+
     @property
-    def base_error_class(self):
+    def base_error_class(self) -> Type[RPCError]:
+        """Base class for RPC protocol implementation."""
         return RPCError
 
     @property
-    def default_error_class(self):
+    def default_error_class(self) -> Type[RPCError]:
+        """The default error class for representing internal exceptions."""
         return InternalServerError
 
     @property
