@@ -8,7 +8,7 @@ from typing import Iterable
 
 def iterable_str_arg(s: str | Iterable[str]) -> list[str]:
     if isinstance(s, str):
-        s = s.replace(",", " ").replace("  ", " ").split()
+        s = s.replace(",", " ").strip().replace("  ", " ").split()
     return list(map(str, s))
 
 
